## START: Set by rpmautospec
## (rpmautospec version 0.8.1)
## RPMAUTOSPEC: autorelease, autochangelog
%define autorelease(e:s:pb:n) %{?-p:0.}%{lua:
    release_number = 1;
    base_release_number = tonumber(rpm.expand("%{?-b*}%{!?-b:1}"));
    print(release_number + base_release_number - 1);
}%{?-e:.%{-e*}}%{?-s:.%{-s*}}%{!?-n:%{?dist}}
## END: Set by rpmautospec

Name:           python-watchfiles
Version:        1.1.0
Release:        %autorelease
Summary:        Simple, modern and high performance file watching and code reload in python
# The main source code is under the MIT license.  See the license field of the
# python3-watchfiles subpackage for the licenses of statically linked rust
# dependencies.
License:        MIT
URL:            https://github.com/samuelcolvin/watchfiles
Source:         %{pypi_source watchfiles}

# Downstream-only: allow a slightly older pytest to support EPEL10
Patch:          0001-Downstream-only-allow-a-slightly-older-pytest-to-sup.patch

BuildRequires:  python3-devel
BuildRequires:  cargo-rpm-macros >= 24
BuildRequires:  tomcli

%global _description %{expand:
Simple, modern and high performance file watching and code reload in python.
Underlying file system notifications are handled by the Notify rust library.}


%description %_description


%package -n python3-watchfiles
Summary:        %{summary}
# The main source code is under the MIT license. This license field includes
# the licenses of statically linked rust dependencies, based on the output of
# %%{cargo_license_summary}:
#
# CC0-1.0
# ISC
# MIT
# MIT OR Apache-2.0
# Unlicense OR MIT
License:        %{shrink:
                MIT AND
                CC0-1.0 AND
                ISC AND
                (MIT OR Apache-2.0) AND
                (Unlicense OR MIT)
                }


%description -n python3-watchfiles %_description


%prep
%autosetup -n watchfiles-%{version} -p1

# Remove unnecessary Python test requirements
tomcli set pyproject.toml lists delitem \
    'dependency-groups.dev' '^(coverage|pytest-(pretty|timeout)).*'

# Remove pytest timeout config
tomcli set pyproject.toml del 'tool.pytest.ini_options.timeout'

# Remove "generate-import-lib" feature for pyo3; applicable only on Windows,
# and not packaged.
tomcli set Cargo.toml lists delitem 'dependencies.pyo3.features' \
    'generate-import-lib'

# Remove unused Cargo config that contains buildflags for Darwin
rm .cargo/config.toml

%cargo_prep


%generate_buildrequires
%pyproject_buildrequires -g dev
%cargo_generate_buildrequires


%build
%cargo_license_summary
%{cargo_license} > LICENSES.dependencies

export RUSTFLAGS='%{build_rustflags}'
%pyproject_wheel


%install
%pyproject_install
%pyproject_save_files -l watchfiles

# The maturin build backend includes the license files, but currently the
# pyproject macros don't mark these files as licenses.
sed -e '/LICENSE/ s/^/%%license /' -i %{pyproject_files}


%check
# We must set the import mode during tests to avoid the watchfiles directory
# (which will not have the compiled module) taking precedence for the import.
# https://docs.pytest.org/en/7.4.x/explanation/pythonpath.html
%pytest --import-mode append -k "${k-}" -v --full-trace


%files -n python3-watchfiles -f %{pyproject_files}
%doc README.md
%{_bindir}/watchfiles


%changelog
## START: Generated by rpmautospec
* Fri Jun 20 2025 Benjamin A. Beasley <code@musicinmybrain.net> - 1.1.0-1
- Update to 1.1.0 (close RHBZ#2372924)

* Wed Jun 04 2025 Benjamin A. Beasley <code@musicinmybrain.net> - 1.0.5-5
- Port to PyO3 0.25 (fix Python 3.14 compatibility)

* Tue Jun 03 2025 Python Maint <python-maint@redhat.com> - 1.0.5-4
- Rebuilt for Python 3.14

* Thu May 15 2025 Benjamin A. Beasley <code@musicinmybrain.net> - 1.0.5-3
- Security fix for CVE-2025-4574 (fix RHBZ#2366569)
- The package was rebuilt with rust-crossbeam-channel 0.5.15.

* Fri Apr 11 2025 Benjamin A. Beasley <code@musicinmybrain.net> - 1.0.5-2
- Assert that .dist-info contains license files

* Tue Apr 08 2025 Benjamin A. Beasley <code@musicinmybrain.net> - 1.0.5-1
- Update to 1.0.5 (close RHBZ#2358260)

* Tue Feb 11 2025 Benjamin A. Beasley <code@musicinmybrain.net> - 1.0.4-3
- Allow a slightly older pytest to support EPEL10

* Tue Feb 11 2025 Benjamin A. Beasley <code@musicinmybrain.net> - 1.0.4-2
- Stop skipping a test that failed on old anyio versions

* Fri Jan 31 2025 Benjamin A. Beasley <code@musicinmybrain.net> - 1.0.4-1
- Update to 1.0.4 (close RHBZ#2336919)

* Sat Jan 18 2025 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.3-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_42_Mass_Rebuild

* Sat Jan 11 2025 Benjamin A. Beasley <code@musicinmybrain.net> - 1.0.3-2
- Patch for rust-notify-8.0.0

* Fri Jan 03 2025 Benjamin A. Beasley <code@musicinmybrain.net> - 1.0.3-1
- Update to 1.0.3

* Fri Jul 19 2024 Fedora Release Engineering <releng@fedoraproject.org> - 0.20.0-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_41_Mass_Rebuild

* Sun Jun 09 2024 Python Maint <python-maint@redhat.com> - 0.20.0-4
- Rebuilt for Python 3.13

* Fri Jan 26 2024 Fedora Release Engineering <releng@fedoraproject.org> - 0.20.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Mon Jan 22 2024 Fedora Release Engineering <releng@fedoraproject.org> - 0.20.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Sun Sep 24 2023 Carl George <carlwgeorge@fedoraproject.org> - 0.20.0-1
- Initial package, resolves rhbz#2240154
## END: Generated by rpmautospec
